Cython: _labelwindow.pyx

Generated by Cython 3.1.8

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: _labelwindow.c

    +1: """

      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_2) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

     2: AdjustedArrayWindow type used for LabelArrays.

     3: """

    +4: ctypedef object databuffer

    typedef PyObject *__pyx_t_7zipline_3lib_12_labelwindow_databuffer;

     5:

     6: include "_windowtemplate.pxi"